diff lisp/vc.el @ 81984:5fe5698ac0fb

* vc-hooks.el (vc-default-workfile-unchanged-p): Pass a list instead of a file. * vc-hg.el (vc-hg-print-log): Fix for multiple files. * vc.el: (vc-directory-exclusion-list): Add .hg and .bzr. (vc-diff-internal): Pass a list instead of a file.
author Dan Nicolaescu <dann@ics.uci.edu>
date Fri, 20 Jul 2007 01:22:18 +0000
parents d3b18c88b7e5
children cd7d70b6659e
line wrap: on
line diff
--- a/lisp/vc.el	Fri Jul 20 00:19:49 2007 +0000
+++ b/lisp/vc.el	Fri Jul 20 01:22:18 2007 +0000
@@ -46,8 +46,9 @@
 
 ;; This mode is fully documented in the Emacs user's manual.
 ;;
 ;; Supported version-control systems presently include CVS, RCS, GNU Arch,
 ;; Subversion, Meta-CVS, and SCCS (or its free replacement, CSSC).
 ;;
 ;; Some features will not work with old RCS versions.  Where
 ;; appropriate, VC finds out which version you have, and allows or
@@ -578,7 +579,8 @@
   :group 'vc
   :version "20.3")
 
-(defcustom vc-directory-exclusion-list '("SCCS" "RCS" "CVS" "MCVS" ".svn" "{arch}")
+(defcustom vc-directory-exclusion-list '("SCCS" "RCS" "CVS" "MCVS" ".svn" 
+					 ".hg" ".bzr" "{arch}")
   "List of directory names to be ignored when walking directory trees."
   :type '(repeat string)
   :group 'vc)
@@ -1934,7 +1936,7 @@
                 (error "diff failed"))
             (if (not vc-diff-knows-L) (setq vc-diff-knows-L 'yes)))
           status)
-      (vc-call diff (list file) rev1 rev2 "*vc-diff"))))
+      (vc-call diff (list file) rev1 rev2 "*vc-diff*"))))
 
 (defun vc-switches (backend op)
   (let ((switches
@@ -46,8 +46,9 @@
 ;; This mode is fully documented in the Emacs user's manual.
 ;;
-;; Supported version-control systems presently include CVS, RCS, GNU Arch,
-;; Subversion, Meta-CVS, and SCCS (or its free replacement, CSSC).
+;; Supported version-control systems presently include CVS, RCS, GNU
+;; Arch, Subversion, Bzr, Mercurial, Meta-CVS, and SCCS (or its free
+;; replacement, CSSC).
 ;;
 ;; Some features will not work with old RCS versions.  Where